import os
import sys
from typing import Iterable
from pathlib import Path

from jinja2 import Environment, FileSystemLoader, Template, exceptions

import config as cfg
from . import app_root_dir, doc_root_dir, resource_dir, template_dir, base_dir

_usage = "Usage: generate.py <provider>"

def make_directories(path):
    # Ensure the directory exists
    directory = os.path.dirname(path)
    if not os.path.exists(directory):
        os.makedirs(directory)
    return True

def load_tmpl(tmpl: str) -> Template:
    env = Environment(loader=FileSystemLoader(template_dir()))
    env.filters["up_or_title"] = up_or_title
    return env.get_template(tmpl)

def up_or_title(pvd: str, s: str) -> str:
    if s in cfg.UPPER_WORDS.get(pvd, ()):
        return s.upper()
    if s in cfg.TITLE_WORDS.get(pvd, {}):
        return cfg.TITLE_WORDS[pvd][s]
    return s.title()

def relative_directory_depth_with_parent(relative_path):
    """
    Returns the depth of a directory structure relative to the current working directory.
    The string representation of the directory level uses ".parent" for each level.
    For example, if the relative_path is 'a/b/c', and all exist, the depth is 3 and the
    string will be '.parent.parent.parent'.

     Example usage:
    # Please run this on your local machine with a valid relative directory path as this environment
    # does not have access to an actual filesystem.

    # relative_path = 'a/b/c'  # Replace with the relative path you want to check
    # depth, parent_string = relative_directory_depth_with_parent(relative_path)
    # print(f"Depth: {depth}, Parent String: {parent_string}")
    """
    depth = 0
    parent_str = ""
    current_path = os.path.abspath(relative_path)
    
    while os.path.dirname(current_path) != current_path:  # Check if we've reached the root
        # Adjust for current directory
        if os.path.exists(current_path) and depth > 3:
            parent_str = '.parent' + parent_str
        current_path = os.path.dirname(current_path)
        depth += 1
        
    return parent_str


def gen_classes(pvd: str, typ: str, paths: Iterable[str], file: str) -> str:
    """Generate all service node classes based on resources paths with class templates."""
    tmpl = load_tmpl(file)

    # TODO: extract the gen class metas for sharing
    # TODO: independent function for generating all pvd/typ/paths pairs
    def _gen_class_meta(path: str) -> dict:
        base = os.path.splitext(path)[0]
        name = "".join([up_or_title(pvd, s) for s in base.split("-")])
        return {"name": name, "icon": path}

    mod_path = os.path.join(app_root_dir(pvd), f"{typ}.py")
    # To get the relative path with respect to the application root directory:
    common_path = Path(__file__).parent  # This would be your common path
    relative_path = os.path.relpath(mod_path, common_path)
    dir_lvl = relative_directory_depth_with_parent(relative_path)
    metas = map(_gen_class_meta, paths)
    aliases = cfg.ALIASES[pvd][typ] if typ in cfg.ALIASES[pvd] else {}
    return tmpl.render(dir_lvl=dir_lvl, pvd=pvd, typ=typ, metas=metas, aliases=aliases)


def gen_apidoc(pvd: str, typ_paths: dict) -> str:
    try:
      default_tmp = cfg.TMPL_APIDOC.split('.')
      tmpl_file = f"{default_tmp[0]}_{pvd}.{default_tmp[1]}"
      tmpl = load_tmpl(tmpl_file)
    except exceptions.TemplateNotFound:
      tmpl = load_tmpl(cfg.TMPL_APIDOC)

    # TODO: remove
    def _gen_class_name(path: str) -> str:
        base = os.path.splitext(path)[0]
        name = "".join([up_or_title(pvd, s) for s in base.split("-")])
        return name

    typ_classes = {}
    for typ, (paths, resource_root) in sorted(typ_paths.items()):
        typ_classes[typ] = []
        for path in paths:
            name = _gen_class_name(path)
            resource_path = os.path.join(resource_root, path)
            alias = cfg.ALIASES[pvd].get(typ, {}).get(name)
            app_root = cfg.DIR_APP_ROOT
            typ_classes[typ].append({"name": name, "alias": alias, "resource_path": resource_path, "app_root": app_root})
    return tmpl.render(pvd=pvd, typ_classes=typ_classes)

def make_module(pvd: str, typ: str, classes: str) -> None:
    """Create a module file"""
    mod_path = os.path.join(app_root_dir(pvd), f"{typ}.py")
    make_directories(mod_path)
    with open(mod_path, "w+") as f:
        f.write(classes)

def make_module_base(pvd: str, typ: str, classes: str) -> None:
    """Create a module file"""
    mod_path = os.path.join(app_root_dir(pvd), f"__init__.py")
    make_directories(mod_path)
    with open(mod_path, "w+") as f:
        f.write(classes)

def make_apidoc(pvd: str, content: str) -> None:
    """Create an api documentation file"""
    mod_path = os.path.join(doc_root_dir(), f"{pvd}.md")
    make_directories(mod_path)
    with open(mod_path, "w+") as f:
        f.write(content)


def generate(pvd: str) -> None:
    """Generates a service node classes."""
    typ_paths = {}
    base = base_dir()
    for root, _, files in os.walk(resource_dir(pvd)):
        # Extract the names and paths from resources.
        files.sort()
        pngs = list(filter(lambda f: f.endswith(".png"), files))
        paths = list(filter(lambda f: "rounded" not in f, pngs))

        # Skip the top-root directory.
        typ = os.path.basename(root)
        
        if typ == pvd:
           typ=""
           resource_root = os.path.relpath(root, base)
           classes = gen_classes(pvd, typ, paths, cfg.TMPL_MODULE_BASE)
           make_module_base(pvd, typ, classes)
           typ_paths[typ] = (paths, resource_root)

        else:
            resource_root = os.path.relpath(root, base)
            classes = gen_classes(pvd, typ, paths, cfg.TMPL_MODULE)
            make_module(pvd, typ, classes)
            typ_paths[typ] = (paths, resource_root)
    # Build API documentation
    apidoc = gen_apidoc(pvd, typ_paths)
    make_apidoc(pvd, apidoc)


if __name__ == "__main__":
    pvd = sys.argv[1]
    if pvd not in cfg.PROVIDERS:
        sys.exit()
    generate(pvd)


import os

def concatenate_md_files_to_string(source_dir):
    """
    Concatenate all .md files from the source directory into a single string.

    :param source_dir: Directory containing .md files.
    :return: A string with the concatenated content of all .md files.
    """
    content = ""
    for filename in os.listdir(source_dir):
        if filename.endswith('.md'):
            file_path = os.path.join(source_dir, filename)
            with open(file_path, 'r') as md_file:
                content += md_file.read() + '\n\n'
    return content

def update_readme_section(readme_path, new_content, start_marker, end_marker):
    with open(readme_path, 'r') as file:
        readme_content = file.readlines()
    
    start_index = next(i for i, line in enumerate(readme_content) if start_marker in line)
    end_index = next(i for i, line in enumerate(readme_content) if end_marker in line)

    updated_content = readme_content[:start_index + 1] + [new_content + '\n'] + readme_content[end_index:]
    
    with open(readme_path, 'w') as file:
        file.writelines(updated_content)

# Example usage
source_directory = 'docs/nodes'  # Replace with your actual directory path
concatenated_content = concatenate_md_files_to_string(source_directory)

# Now, use the existing function to update the README section
readme_path = 'README.md'
start_marker = '<!-- START_SECTION:Documentation -->'
end_marker = '<!-- END_SECTION:Documentation -->'
update_readme_section(readme_path, concatenated_content, start_marker, end_marker)


"""
resources.py provides useful tools for resources processing.

There are 2 commands available.
- clean: clean and unify the resources file names with some rules.
- round: generate the rounded images from the original squared images.
"""

import os
import subprocess
import sys

import config as cfg
from . import resource_dir

_usage = "Usage: resource.py <cmd> <pvd>"


def cleaner_onprem(f):
    f = f.replace("_", "-")
    return f.lower()


def cleaner_aws(f):
    f = f.replace("_", "-")
    f = f.replace("@4x", "")
    f = f.replace("@5x", "")
    f = f.replace("2.0", "2-0")
    f = f.replace("-light-bg4x", "")
    f = f.replace("-light-bg", "")
    for p in cfg.FILE_PREFIXES["aws"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_azure(f):
    f = f.replace("_", "-")
    f = f.replace("(", "").replace(")", "")
    f = "-".join(f.split())
    for p in cfg.FILE_PREFIXES["azure"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_gcp(f):
    f = f.replace("_", "-")
    f = "-".join(f.split())
    for p in cfg.FILE_PREFIXES["gcp"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_ibm(f):
    f = f.replace("_", "-")
    f = "-".join(f.split())
    for p in cfg.FILE_PREFIXES["ibm"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_firebase(f):
    f = f.replace("_", "-")
    f = "-".join(f.split())
    for p in cfg.FILE_PREFIXES["firebase"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_k8s(f):
    f = f.replace("-256", "")
    for p in cfg.FILE_PREFIXES["k8s"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()

def cleaner_digitalocean(f):
    f = f.replace("-32", "")
    for p in cfg.FILE_PREFIXES["digitalocean"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_alibabacloud(f):
    for p in cfg.FILE_PREFIXES["alibabacloud"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_oci(f):
    f = f.replace(" ", "-")
    f = f.replace("_", "-")
    for p in cfg.FILE_PREFIXES["oci"]:
        if f.startswith(p):
            f = f[len(p) :]
            break
    return f.lower()


def cleaner_programming(f):
    return f.lower()


def cleaner_generic(f):
    return f.lower()


def cleaner_saas(f):
    return f.lower()


def cleaner_elastic(f):
    return f.lower()


def cleaner_outscale(f):
    return f.lower()


def cleaner_openstack(f):
    return f.lower()


cleaners = {
    "onprem": cleaner_onprem
    "aws": cleaner_aws,
    "azure": cleaner_azure,
    "digitalocean": cleaner_digitalocean,
    "gcp": cleaner_gcp,
    "ibm": cleaner_ibm,
    "firebase": cleaner_firebase,
    "k8s": cleaner_k8s,
    "alibabacloud": cleaner_alibabacloud,
    "oci": cleaner_oci,
    "programming": cleaner_programming,
    "saas": cleaner_saas,
    "elastic": cleaner_elastic,
    "outscale": cleaner_outscale,
    "generic": cleaner_generic,
    "openstack": cleaner_openstack,
}


def clean_png(pvd: str) -> None:
    """Refine the resources files names."""

    def _rename(base: str, png: str):
        new = cleaners[pvd](png)
        old_path = os.path.join(base, png)
        new_path = os.path.join(base, new)
        os.rename(old_path, new_path)

    for root, _, files in os.walk(resource_dir(pvd)):
        pngs = filter(lambda f: f.endswith(".png"), files)
        [_rename(root, png) for png in pngs]


def round_png(pvd: str) -> None:
    """Round the images."""

    def _round(base: str, path: str):
        path = os.path.join(base, path)
        subprocess.run([cfg.CMD_ROUND, *cfg.CMD_ROUND_OPTS, path])

    for root, _, files in os.walk(resource_dir(pvd)):
        pngs = filter(lambda f: f.endswith(".png"), files)
        paths = filter(lambda f: "rounded" not in f, pngs)
        [_round(root, path) for path in paths]


def svg2png(pvd: str) -> None:
    """Convert the svg into png"""

    def _convert(base: str, path: str):
        path = os.path.join(base, path)
        subprocess.run([cfg.CMD_SVG2PNG, *cfg.CMD_SVG2PNG_OPTS, path])
        subprocess.run(["rm", path])

    for root, _, files in os.walk(resource_dir(pvd)):
        svgs = filter(lambda f: f.endswith(".svg"), files)
        [_convert(root, path) for path in svgs]


def svg2png2(pvd: str) -> None:
    """Convert the svg into png using image magick"""

    def _convert(base: str, path: str):
        path_src = os.path.join(base, path)
        path_dest = path_src.replace(".svg", ".png")
        subprocess.run([cfg.CMD_SVG2PNG_IM, *cfg.CMD_SVG2PNG_IM_OPTS, path_src, path_dest])
        subprocess.run(["rm", path_src])

    for root, _, files in os.walk(resource_dir(pvd)):
        svgs = filter(lambda f: f.endswith(".svg"), files)
        [_convert(root, path) for path in svgs]


# fmt: off
commands = {
    "clean": clean_png,
    "round": round_png,
    "svg2png": svg2png,
    "svg2png2": svg2png2,
}
# fmt: on

if __name__ == "__main__":
    if len(sys.argv) < 3:
        print(_usage)
        sys.exit()

    cmd = sys.argv[1]
    pvd = sys.argv[2]
    if cmd not in commands:
        sys.exit()
    if pvd not in cfg.PROVIDERS:
        sys.exit()
    commands[cmd](pvd)


import unittest
from diagrams import Node, Diagram, Cluster
from ExtendedDiagramIcons.dnsproviders.namecheap import Provider, Namecheap_Api, Namecheap_Domain
from ExtendedDiagramIcons.generic import Github, Jira, Report_Portal, Software_Engineer
from ExtendedDiagramIcons.octopusdeploy import Octopus_Deploy, Octopus_Server_Node, Octopus_Worker_Node, Octopus_Worker_Pool, Pipeline, Release
from ExtendedDiagramIcons.digitalocean import Project

class TestCase(unittest.TestCase):
    def test_icon_map(self):
        with Diagram("All Icons", show=False):
            Provider("Namecheap")
            Namecheap_Api("Namecheap API")
            Namecheap_Domain("Namecheap Domain")
            Github("GitHub")
            Jira("JIRA")
            Report_Portal("Report Portal")
            Software_Engineer("Software Engineer")
            Octopus_Deploy("Octopus_Deploy")
            Octopus_Server_Node("Octopus_Server_Node")
            Octopus_Worker_Node("Octopus_Worker_Node")
            Octopus_Worker_Pool("Octopus_Worker_Pool")
            Pipeline("Pipeline")
            Release("Release")
            Project("DO Project")

if __name__ == "__main__":
    unittest.main()
    print(Test.assetEqual)


import os
from pathlib import Path

import config as cfg


def base_dir() -> str:
    return Path(os.path.abspath(os.path.dirname(__file__))).parent


def app_root_dir(pvd: str) -> str:
    return os.path.join(base_dir(), cfg.DIR_APP_ROOT, pvd)


def doc_root_dir() -> str:
    return os.path.join(base_dir(), cfg.DIR_DOC_ROOT)


def resource_dir(pvd: str) -> str:
    return os.path.join(base_dir(), cfg.DIR_RESOURCE, pvd)


def template_dir() -> str:
    return os.path.join(base_dir(), cfg.DIR_TEMPLATE)


# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _DigitalOcean(Node):
    _type = "digitalocean"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/digitalocean"


class Project(_DigitalOcean):
    _icon = "project.png"

# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _DNSProviders(Node):
    _type = "dnsproviders"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/dnsproviders"



# Aliases



import sys

def update_readme_section(readme_path, new_content, start_marker, end_marker):
    with open(readme_path, 'r') as file:
        readme_content = file.readlines()
    
    start_index = next(i for i, line in enumerate(readme_content) if start_marker in line)
    end_index = next(i for i, line in enumerate(readme_content) if end_marker in line)

    updated_content = readme_content[:start_index + 1] + [new_content + '\n'] + readme_content[end_index:]
    
    with open(readme_path, 'w') as file:
        file.writelines(updated_content)

# Function to create an SVG badge with "Dev Build" on one side and a number on the other
def create_svg_badge_dev(build_number):
    svg_template = f"""<svg xmlns="http://www.w3.org/2000/svg" width="150" height="20">
    <g xmlns="http://www.w3.org/2000/svg" font-family="'DejaVu Sans',Verdana,Geneva,sans-serif" font-size="11">
      <path id="workflow-bg" d="M0,3 C0,1.3431 1.3552,0 3.02702703,0 L106,0 L106,20 L3.02702703,20 C1.3552,20 0,18.6569 0,17 L0,3 Z" fill="rgb(16, 16, 15)" fill-rule="nonzero"/>
      <text fill="#010101" fill-opacity=".3">
        <tspan x="22.1981982" y="15" aria-hidden="true">Dev Build</tspan>
      </text>
      <text fill="#FFFFFF">
        <tspan x="22.1981982" y="14">Dev Build</tspan>
      </text>
    </g>
    <rect x="55%" width="40%" height="100%" fill="rgb(99, 194, 97)"/>

    <text x="75%" y="70%" font-family="DejaVu Sans',Verdana,Geneva,sans-serif" font-size="11" fill="#fff" text-anchor="middle">{build_number}</text>
    <path xmlns="http://www.w3.org/2000/svg" fill="#959DA5" d="M11 3c-3.868 0-7 3.132-7 7a6.996 6.996 0 0 0 4.786 6.641c.35.062.482-.148.482-.332 0-.166-.01-.718-.01-1.304-1.758.324-2.213-.429-2.353-.822-.079-.202-.42-.823-.717-.99-.245-.13-.595-.454-.01-.463.552-.009.946.508 1.077.718.63 1.058 1.636.76 2.039.577.061-.455.245-.761.446-.936-1.557-.175-3.185-.779-3.185-3.456 0-.762.271-1.392.718-1.882-.07-.175-.315-.892.07-1.855 0 0 .586-.183 1.925.718a6.5 6.5 0 0 1 1.75-.236 6.5 6.5 0 0 1 1.75.236c1.338-.91 1.925-.718 1.925-.718.385.963.14 1.68.07 1.855.446.49.717 1.112.717 1.882 0 2.686-1.636 3.28-3.194 3.456.254.219.473.639.473 1.295 0 .936-.009 1.689-.009 1.925 0 .184.131.402.481.332A7.011 7.011 0 0 0 18 10c0-3.867-3.133-7-7-7z"/>
</svg>"""
    return svg_template

# Function to create an SVG badge with "Stable Build" on one side and a number on the other
def create_svg_badge_stable(build_number):
    svg_template = f"""<svg xmlns="http://www.w3.org/2000/svg" width="150" height="20">
    <g xmlns="http://www.w3.org/2000/svg" font-family="'DejaVu Sans',Verdana,Geneva,sans-serif" font-size="11">
      <path id="workflow-bg" d="M0,3 C0,1.3431 1.3552,0 3.02702703,0 L106,0 L106,20 L3.02702703,20 C1.3552,20 0,18.6569 0,17 L0,3 Z" fill="rgb(16, 16, 15)" fill-rule="nonzero"/>
      <text fill="#010101" fill-opacity=".3">
        <tspan x="22.1981982" y="15" aria-hidden="true">Stable Build</tspan>
      </text>
      <text fill="#FFFFFF">
        <tspan x="22.1981982" y="14">Stable Build</tspan>
      </text>
    </g>
    <g xmlns="http://www.w3.org/2000/svg" transform="translate(106)" font-family="'DejaVu Sans',Verdana,Geneva,sans-serif" font-size="11">
      <path d="M0 0h46.939C48.629 0 50 1.343 50 3v14c0 1.657-1.37 3-3.061 3H0V0z" id="state-bg" fill="rgb(99, 194, 97)" fill-rule="nonzero"/>
      <text fill="#010101" fill-opacity=".3" aria-hidden="true">
        <tspan x="4" y="15">{build_number}</tspan>
      </text>
      <text fill="#FFFFFF">
        <tspan x="4" y="14">{build_number}</tspan>
      </text>
    </g>
    <path xmlns="http://www.w3.org/2000/svg" fill="#959DA5" d="M11 3c-3.868 0-7 3.132-7 7a6.996 6.996 0 0 0 4.786 6.641c.35.062.482-.148.482-.332 0-.166-.01-.718-.01-1.304-1.758.324-2.213-.429-2.353-.822-.079-.202-.42-.823-.717-.99-.245-.13-.595-.454-.01-.463.552-.009.946.508 1.077.718.63 1.058 1.636.76 2.039.577.061-.455.245-.761.446-.936-1.557-.175-3.185-.779-3.185-3.456 0-.762.271-1.392.718-1.882-.07-.175-.315-.892.07-1.855 0 0 .586-.183 1.925.718a6.5 6.5 0 0 1 1.75-.236 6.5 6.5 0 0 1 1.75.236c1.338-.91 1.925-.718 1.925-.718.385.963.14 1.68.07 1.855.446.49.717 1.112.717 1.882 0 2.686-1.636 3.28-3.194 3.456.254.219.473.639.473 1.295 0 .936-.009 1.689-.009 1.925 0 .184.131.402.481.332A7.011 7.011 0 0 0 18 10c0-3.867-3.133-7-7-7z"/>
</svg>"""
    return svg_template

type = sys.argv[1] if len(sys.argv) > 1 else "unknown"

if type == "stable":
    # Taking argument from bash (the build number) and storing it in a variable
    build_number = sys.argv[2] if len(sys.argv) > 1 else "unknown"

    # Create the SVG badge
    svg_badge = create_svg_badge_stable(build_number)

    # Save the SVG badge to a file
    with open("docs/data/stable_build.svg", "w") as file:
        file.write(svg_badge)

    print("SVG badge created with build number:", build_number)

    string = f"""
- Install latest stable build: `pip install ExtendedDiagramIcons=={build_number}`
    """

    # Now, use the existing function to update the README section
    readme_path = 'README.md'
    start_marker = '<!-- START_SECTION:InstallLatestStable -->'
    end_marker = '<!-- END_SECTION:InstallLatestStable -->'
    update_readme_section(readme_path, string, start_marker, end_marker)
    
    readme_path = 'README.md'
    start_marker = '<!-- START_SECTION:InstallLatestDevelopment -->'
    end_marker = '<!-- END_SECTION:InstallLatestDevelopment -->'
    update_readme_section(readme_path, "", start_marker, end_marker)

    print("Updated README.mdwith build number:", build_number)

elif type == "dev":
    # Taking argument from bash (the build number) and storing it in a variable
    build_number = sys.argv[2] if len(sys.argv) > 1 else "unknown"

    # Create the SVG badge
    svg_badge = create_svg_badge_dev(build_number)

    # Save the SVG badge to a file
    with open("docs/data/development_build.svg", "w") as file:
        file.write(svg_badge)

    print("SVG badge created with build number:", build_number)

    string = f"""
- Install latest development build: `pip install ExtendedDiagramIcons=={build_number}`
    """

    # Now, use the existing function to update the README section
    readme_path = 'README.md'
    start_marker = '<!-- START_SECTION:InstallLatestDevelopment -->'
    end_marker = '<!-- END_SECTION:InstallLatestDevelopment -->'
    update_readme_section(readme_path, string, start_marker, end_marker)

    start_marker = '<!-- START_SECTION:InstallLatestStable -->'
    end_marker = '<!-- END_SECTION:InstallLatestStable -->'
    update_readme_section(readme_path, "", start_marker, end_marker)

    print("Updated README.mdwith build number:", build_number)




import os
from setuptools import setup, find_packages

def get_version():
    basedir = os.path.dirname(__file__)
    with open(os.path.join(basedir, "__init__.py")) as f:
        locals = {}
        exec(f.read(), locals)
        return locals["__version__"]

def generate_package_data(package_name, resource_dir):
    """
    Generate the package_data dictionary for setuptools setup function.
    It scans the resource_dir for all subdirectories and files to include.

    :param package_name: Name of the Python package
    :param resource_dir: Directory containing resources relative to the package
    :return: A dictionary suitable for the package_data argument in setup()

    # Example usage:
    # This would be used in your setup.py file.
    # package_data = generate_package_data('my_package', 'my_package/resources')

    # Note: This code is for demonstration and should be adjusted according to your actual package structure.
    # The function must be run in an environment where it can access the filesystem of the package.
    """
    package_data = {package_name: []}
    for root, dirs, files in os.walk(resource_dir):
        for file in files:
            if file.endswith('.png'):  # Only select .png files
                # Construct the path relative to the package
                path = os.path.join(root, file)
                relative_path = os.path.relpath(path, package_name)

                # Add the relative path to the package_data
                package_data[package_name].append(relative_path)

    return package_data

package_name = 'ExtendedDiagramIcons'  # Replace with your actual package name
basedir = os.path.dirname(__file__)
resource_directory = os.path.join(basedir, "resources")  # Adjust the path to your resources directory

package_data = generate_package_data(package_name, resource_directory)
print("---------------------")
print(package_data)
setup(
    name="ExtendedDiagramIcons",
    version=get_version(),
    author="Joshua Duma",
    author_email="joshua.duma@trader.ca",
    description="This is intended to be used in a project that uses the diagrams (diagrams as code) python package as an extention of the icons.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="",
    include_package_data=True,
    package_data=package_data,
    repository="https://github.com/JoshuaDuma/ExtendedDiagramIcons",
    packages=find_packages(),
    install_requires=[
        "diagrams>=0.23.4"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)


# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _OctopusDeploy(Node):
    _type = "octopusdeploy"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/octopusdeploy"


class Octopus_Deploy(_OctopusDeploy):
    _icon = "octopus_deploy.png"
class Octopus_Server_Node(_OctopusDeploy):
    _icon = "octopus_server_node.png"
class Octopus_Worker_Node(_OctopusDeploy):
    _icon = "octopus_worker_node.png"
class Octopus_Worker_Pool(_OctopusDeploy):
    _icon = "octopus_worker_pool.png"
class Pipeline(_OctopusDeploy):
    _icon = "pipeline.png"
class Release(_OctopusDeploy):
    _icon = "release.png"

# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _Generic(Node):
    _type = "generic"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/generic"


class Github(_Generic):
    _icon = "github.png"
class Jira(_Generic):
    _icon = "jira.png"
class Report_Portal(_Generic):
    _icon = "report_portal.png"
class Software_Engineer(_Generic):
    _icon = "software_engineer.png"

# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _DNSProviders
from pathlib import Path

class _Namecheap(_DNSProviders):
    _type = "namecheap"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/dnsproviders/namecheap"


class Namecheap_Api(_Namecheap):
    _icon = "namecheap_api.png"
class Namecheap_Domain(_Namecheap):
    _icon = "namecheap_domain.png"
class Provider(_Namecheap):
    _icon = "provider.png"

# Aliases
